Data Reduction
=================

.. toctree::

    ref_pix.rst

.. rubric:: Summary

.. autosummary::

    pynrc.reduce.ref_pixels.NRC_refs
    pynrc.reduce.ref_pixels.reffix_hxrg
    pynrc.reduce.ref_pixels.reffix_amps
    pynrc.reduce.ref_pixels.ref_filter
    pynrc.reduce.ref_pixels.calc_avg_amps
    pynrc.reduce.ref_pixels.calc_avg_cols
    pynrc.reduce.ref_pixels.calc_col_smooth
    pynrc.reduce.ref_pixels.smooth_fft
